@@ -2,7 +2,7 @@
 
 from typing import Literal, Optional
 
-from pydantic import BaseModel, PositiveInt
+from pydantic import BaseModel, Extra, PositiveInt
 
 from .base import FredBase, Json
 
@@ -37,6 +37,9 @@ class ReleaseApiParameters(BaseModel):
     element_id: Optional[int] = None
     tag_names: Optional[str] = None
 
+    class Config:
+        extra = Extra.allow
+
 
 class FredRelease(FredBase):
     """FRED API Release Release endpoints."""
