@@ -3,7 +3,7 @@
 
 from typing import Literal, Optional
 
-from pydantic import BaseModel, PositiveInt
+from pydantic import BaseModel, Extra, PositiveInt
 
 from .base import FredBase, Json
 
@@ -21,6 +21,9 @@ class SourceApiParameters(BaseModel):
     ] = None
     sort_order: Optional[Literal["asc", "desc"]] = None
 
+    class Config:
+        extra = Extra.allow
+
 
 class FredSources(FredBase):
     def get_sources(self, **kwargs) -> Json:
